Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6)

Unified Diff: sdk/lib/core/list.dart

Issue 838463002: Change List/Set/Map/Queue.from constructrs to accept any iterable. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/core/list.dart
diff --git a/sdk/lib/core/list.dart b/sdk/lib/core/list.dart
index a9d82c8b00fee62bad6f2d4227c753209f59af7f..a6ae897e7ee4b6e6e08f5871be713d9356e0519c 100644
--- a/sdk/lib/core/list.dart
+++ b/sdk/lib/core/list.dart
@@ -87,14 +87,14 @@ abstract class List<E> implements Iterable<E>, EfficientLength {
external factory List.filled(int length, E fill);
/**
- * Creates a list and initializes it using the contents of [other].
+ * Creates a list containing all of [elements].
*
* The [Iterator] of [other] provides the order of the objects.
*
- * This constructor returns a growable list if [growable] is true;
+ * This constructor returns a growable list when [growable] is true;
* otherwise, it returns a fixed-length list.
*/
- external factory List.from(Iterable other, { bool growable: true });
+ external factory List.from(Iterable elements, { bool growable: true });
/**
* Generates a list of values.
@@ -87,14 +87,14 @@ abstract class List<E> implements Iterable<E>, EfficientLength {
*
- * The [Iterator] of [other] provides the order of the objects.
+ * The [Iterator] of [elements] provides the order of the elements.
*

Powered by Google App Engine
This is Rietveld 408576698